==> zio-aws-iot1clickdevices_2.13-5.17.126.2-sources.jar: zio/aws/iot1clickdevices/model/UntagResourceRequest.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class UntagResourceRequest(
    resourceArn: __string,
    tagKeys: Iterable[__string]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.UntagResourceRequest = {
    import UntagResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.UntagResourceRequest
      .builder()
      .resourceArn(__string.unwrap(resourceArn): java.lang.String)
      .tagKeys(tagKeys.map { item =>
        __string.unwrap(item): java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.iot1clickdevices.model.UntagResourceRequest.ReadOnly =
    zio.aws.iot1clickdevices.model.UntagResourceRequest.wrap(buildAwsValue())
}
object UntagResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.UntagResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.UntagResourceRequest =
      zio.aws.iot1clickdevices.model.UntagResourceRequest(resourceArn, tagKeys)
    def resourceArn: __string
    def tagKeys: List[__string]
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
    def getTagKeys: ZIO[Any, Nothing, List[__string]] = ZIO.succeed(tagKeys)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.UntagResourceRequest
  ) extends zio.aws.iot1clickdevices.model.UntagResourceRequest.ReadOnly {
    override val resourceArn: __string =
      zio.aws.iot1clickdevices.model.primitives.__string(impl.resourceArn())
    override val tagKeys: List[__string] = impl
      .tagKeys()
      .asScala
      .map { item =>
        zio.aws.iot1clickdevices.model.primitives.__string(item)
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.UntagResourceRequest
  ): zio.aws.iot1clickdevices.model.UntagResourceRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-iot1clickdevices_2.13-5.17.130.8-sources.jar: zio/aws/iot1clickdevices/model/UntagResourceRequest.scala <==
package zio.aws.iot1clickdevices.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.iot1clickdevices.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class UntagResourceRequest(
    resourceArn: __string,
    tagKeys: Iterable[__string]
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot1clickdevices.model.UntagResourceRequest = {
    import UntagResourceRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot1clickdevices.model.UntagResourceRequest
      .builder()
      .resourceArn(resourceArn: java.lang.String)
      .tagKeys(tagKeys.map { item =>
        item: java.lang.String
      }.asJavaCollection)
      .build()
  }
  def asReadOnly: zio.aws.iot1clickdevices.model.UntagResourceRequest.ReadOnly =
    zio.aws.iot1clickdevices.model.UntagResourceRequest.wrap(buildAwsValue())
}
object UntagResourceRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot1clickdevices.model.UntagResourceRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot1clickdevices.model.UntagResourceRequest =
      zio.aws.iot1clickdevices.model.UntagResourceRequest(resourceArn, tagKeys)
    def resourceArn: __string
    def tagKeys: List[__string]
    def getResourceArn: ZIO[Any, Nothing, __string] = ZIO.succeed(resourceArn)
    def getTagKeys: ZIO[Any, Nothing, List[__string]] = ZIO.succeed(tagKeys)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.UntagResourceRequest
  ) extends zio.aws.iot1clickdevices.model.UntagResourceRequest.ReadOnly {
    override val resourceArn: __string = impl.resourceArn(): __string
    override val tagKeys: List[__string] = impl
      .tagKeys()
      .asScala
      .map { item =>
        item: __string
      }
      .toList
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot1clickdevices.model.UntagResourceRequest
  ): zio.aws.iot1clickdevices.model.UntagResourceRequest.ReadOnly = new Wrapper(
    impl
  )
}
